"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useInstallReferrer;

var _react = require("react");

var _reactNative = require("react-native");

const initialState = {
  status: 'idle',
  data: undefined,
  error: undefined
};

function useInstallReferrer() {
  const [{
    status,
    data,
    error
  }, setState] = (0, _react.useReducer)((s, a) => ({ ...s,
    ...a
  }), initialState);

  const setData = details => setState({
    data: details,
    status: 'resolved'
  });

  const setError = errorMessage => setState({
    error: errorMessage,
    status: 'rejected'
  });

  (0, _react.useEffect)(() => {
    if (_reactNative.Platform.OS === 'android') _reactNative.NativeModules.PlayInstallReferrerModule.getReferrer().then(setData).catch(err => {
      setError(err.message);
    });
  }, []);
  return {
    isIdle: status === 'idle',
    isLoading: status === 'pending',
    isError: status === 'rejected',
    isSuccess: status === 'resolved',
    data,
    error
  };
}
//# sourceMappingURL=index.js.map