import { useEffect, useReducer } from 'react';
import { NativeModules, Platform } from 'react-native';
const initialState = {
  status: 'idle',
  data: undefined,
  error: undefined
};
export default function useInstallReferrer() {
  const [{
    status,
    data,
    error
  }, setState] = useReducer((s, a) => ({ ...s,
    ...a
  }), initialState);

  const setData = details => setState({
    data: details,
    status: 'resolved'
  });

  const setError = errorMessage => setState({
    error: errorMessage,
    status: 'rejected'
  });

  useEffect(() => {
    if (Platform.OS === 'android') NativeModules.PlayInstallReferrerModule.getReferrer().then(setData).catch(err => {
      setError(err.message);
    });
  }, []);
  return {
    isIdle: status === 'idle',
    isLoading: status === 'pending',
    isError: status === 'rejected',
    isSuccess: status === 'resolved',
    data,
    error
  };
}
//# sourceMappingURL=index.js.map